You can read more about how to find older patent records in [Intellectual property: patents for invention research guide](https://www.nationalarchives.gov.uk/help-with-your-research/research-guides/patents-of-invention/){target="\_blank"}; [Intellectual property: registered designs 1839-1991 research guide](https://www.nationalarchives.gov.uk/help-with-your-research/research-guides/registered-designs-1839-1991/){target="\_blank"} or [Intellectual property: trademarks 1876-1938 research guide](https://www.nationalarchives.gov.uk/help-with-your-research/research-guides/trade-marks/){target="\_blank"}.
